<template>
  <Modal
    :value="visible"
    title="查看车辆异常"
    draggable
    sticky
    :mask="false"
    @on-visible-change="visibleChange"
    :width="456"
  >
    <Table :columns="columns" :data="list" size="small"> </Table>
    <template #footer>
      <Button type="primary" @click="close">关闭</Button>
    </template>
  </Modal>
</template>

<script>
import { webConfig } from "@/utils";
import HttpRequest from "@/api/request.js";
import { setLocalStorage, getLocalStorage } from "@/utils";
export default {
  name: "MonitorModalError",
  data() {
    return {
      httpRequest: new HttpRequest(webConfig.apiUrl),
      columns: [
        {
          title: "时间",
          key: "dt",
          width: 150,
        },
        {
          title: "异常",
          key: "error",
        },
      ],
      list: [],
    };
  },
  model: {
    prop: "visible",
    event: "visible-change",
  },
  props: {
    visible: Boolean,
    selectedAGVName: String,
  },
  methods: {
    visibleChange(value) {
      this.$emit("visible-change", value);
    },
    close() {
      this.$emit("visible-change", false);
    },
    loadData() {
      if (!this.selectedAGVName) return;
      const key = `abnormal.${this.selectedAGVName}`;
      this.list = getLocalStorage(key) || [];
      this.httpRequest
        .post(`vehicles/abnormal/${this.selectedAGVName}`)
        .then((res) => {
          var list = [
            {
              dt: new Date().toLocaleString(),
              error: res,
            },
            ...this.list,
          ];
          setLocalStorage(key, list);
          this.list = list;
        })
        .catch((err) => {
          this.$Message.error({ content: err, duration: 10 });
        });
    },
  },
  mounted() {
    this.loadData();
  },
  watch: {
    selectedAGVName() {
      if (this.selectedAGVName) this.loadData();
    },
  },
};
</script>

<style lang="less" scoped>
</style>